@@ -504,7 +504,7 @@ public class PackageManager {
             	// but package file hosted on github (which are most of them)
             	// produce a HttpURLConnection.HTTP_FORBIDDEN for some reason
             	throw new IOException("Could not find package at URL\n" + templateURL + "\n"
-            			+ "The server may be bussy, or network may be down.\n"
+            			+ "The server may be busy, or network may be down.\n"
             			+ "If you suspect there is a problem with the URL \n"
             			+ "(the URL may have a typo, or the file was removed)\n"
             			+ "please contact the package maintainer.\n");
